@@ -170,14 +170,14 @@ orderMinPriority(minprior_t *minprior, options_t *options, timings_t *cpus)
      check whether nstages is valid
      ------------------------------ */
   if ((nstages < 1) || (nstages > nvtx))
-   { Rf_error("\nError in function orderMinPriority\n"
+   { rcpp_error("\nError in function orderMinPriority\n"
           "  no valid number of stages in multisector (#stages = %d)\n",
           nstages);
      /*quit();*/
    }
 
   if ((nstages < 2) && (ordtype != MINIMUM_PRIORITY))
-   { Rf_error("\nError in function orderMinPriority\n"
+   { rcpp_error("\nError in function orderMinPriority\n"
           "  not enough stages in multisector (#stages = %d)\n", nstages);
      /*quit();*/
    }
@@ -202,7 +202,7 @@ orderMinPriority(minprior_t *minprior, options_t *options, timings_t *cpus)
        eliminateStage(minprior, nstages-1, scoretype, cpus);
        break;
      default:
-       Rf_error("\nError in function orderMinPriority\n"
+       rcpp_error("\nError in function orderMinPriority\n"
             "  unrecognized ordering type %d\n", ordtype);
        /*quit();*/
    }
@@ -212,7 +212,7 @@ orderMinPriority(minprior_t *minprior, options_t *options, timings_t *cpus)
      ------------------------------------------- */
   if ((ordtype != MINIMUM_PRIORITY) && (options[OPTION_MSGLVL] > 1))
     for (istage = 0; istage < nstages; istage++)
-      Rf_warning("%4d. stage: #steps %6d, weight %6d, nzl %8d, ops %e\n", istage,
+      rcpp_warning("%4d. stage: #steps %6d, weight %6d, nzl %8d, ops %e\n", istage,
              minprior->stageinfo[istage].nstep,
              minprior->stageinfo[istage].welim,
              minprior->stageinfo[istage].nzf,
@@ -252,7 +252,7 @@ eliminateStage(minprior_t *minprior, PORD_INT istage, PORD_INT scoretype, timing
   score = Gelim->score;
 
 #ifdef DEBUG
-  Rf_warning("\nSTARTING NEW ELIMINATION STAGE (nedges %d, maxedges %d)\n\n",
+  rcpp_warning("\nSTARTING NEW ELIMINATION STAGE (nedges %d, maxedges %d)\n\n",
          Gelim->G->nedges, Gelim->maxedges);
   if (istage> 0) printElimGraph(Gelim);
   /* waitkey(); */
@@ -290,10 +290,10 @@ eliminateStage(minprior_t *minprior, PORD_INT istage, PORD_INT scoretype, timing
      nreach = minprior->nreach;
 
 #ifdef BE_CAUTIOUS
-     Rf_warning("checking arrays auxtmp and auxbin\n");
+     rcpp_warning("checking arrays auxtmp and auxbin\n");
      for (u = 0; u < nvtx; u++)
        if ((auxtmp[u] >= *pflag) || (auxbin[u] != -1))
-        { Rf_error("ERROR: flag = %d, auxtmp[%d] = %d, auxbin[%d] = %d\n",
+        { rcpp_error("ERROR: flag = %d, auxtmp[%d] = %d, auxbin[%d] = %d\n",
                  *pflag, u, auxtmp[u], u, auxbin[u]);
           /*quit();*/
         }
@@ -314,10 +314,10 @@ eliminateStage(minprior_t *minprior, PORD_INT istage, PORD_INT scoretype, timing
      pord_stoptimer(cpus[TIME_FINDINODES]);
 
 #ifdef BE_CAUTIOUS
-     Rf_warning("checking arrays auxtmp and auxbin\n");
+     rcpp_warning("checking arrays auxtmp and auxbin\n");
      for (u = 0; u < nvtx; u++)
        if ((auxtmp[u] >= *pflag) || (auxbin[u] != -1))
-        { Rf_error("ERROR: flag = %d, auxtmp[%d] = %d, auxbin[%d] = %d\n",
+        { rcpp_error("ERROR: flag = %d, auxtmp[%d] = %d, auxbin[%d] = %d\n",
                  *pflag, u, auxtmp[u], u, auxbin[u]);
           /*quit();*/
         }
@@ -384,7 +384,7 @@ eliminateStep(minprior_t *minprior, PORD_INT istage, PORD_INT scoretype)
   score = Gelim->score;
 
 #ifdef DEBUG
-  Rf_warning("\nStarting new elimination step (nedges %d, maxedges %d)\n",
+  rcpp_warning("\nStarting new elimination step (nedges %d, maxedges %d)\n",
          Gelim->G->nedges, Gelim->maxedges);
   /* waitkey(); */
 #endif
@@ -430,11 +430,11 @@ eliminateStep(minprior_t *minprior, PORD_INT istage, PORD_INT scoretype)
       }
 
 #ifdef DEBUG
-     Rf_warning("Node %d (weight %d, score %d) eliminated: (boundary weight %d)\n",
+     rcpp_warning("Node %d (weight %d, score %d) eliminated: (boundary weight %d)\n",
             u, vwghtu, minscr, degree[u]);
      for (i = istart; i < istop; i++)
-       Rf_warning("%4d (degree %2d)", adjncy[i], degree[adjncy[i]]);
-     Rf_warning("\n");
+       rcpp_warning("%4d (degree %2d)", adjncy[i], degree[adjncy[i]]);
+     rcpp_warning("\n");
 #endif
 
       /* ---------------------------------------------------------------
