@@ -56,7 +56,7 @@ void FM_2WayNodeRefine2Sided(ctrl_t *ctrl, graph_t *graph, idx_t niter)
   badmaxpwgt = (idx_t)(mult*(pwgts[0]+pwgts[1]+pwgts[2]));
 
   IFSET(ctrl->dbglvl, METIS_DBG_REFINE,
-    Rf_warning("Partitions-N2: [%6"PRIDX" %6"PRIDX"] Nv-Nb[%6"PRIDX" %6"PRIDX"]. ISep: %6"PRIDX"\n", pwgts[0], pwgts[1], graph->nvtxs, graph->nbnd, graph->mincut));
+    rcpp_warning("Partitions-N2: [%6"PRIDX" %6"PRIDX"] Nv-Nb[%6"PRIDX" %6"PRIDX"]. ISep: %6"PRIDX"\n", pwgts[0], pwgts[1], graph->nvtxs, graph->nbnd, graph->mincut));
 
   for (pass=0; pass<niter; pass++) {
     iset(nvtxs, -1, moved);
@@ -190,7 +190,7 @@ void FM_2WayNodeRefine2Sided(ctrl_t *ctrl, graph_t *graph, idx_t niter)
       mptr[nswaps+1] = nmind;
 
       IFSET(ctrl->dbglvl, METIS_DBG_MOVEINFO,
-            Rf_warning("Moved %6"PRIDX" to %3"PRIDX", Gain: %5"PRIDX" [%5"PRIDX"] [%4"PRIDX" %4"PRIDX"] \t[%5"PRIDX" %5"PRIDX" %5"PRIDX"]\n", higain, to, g[to], g[other], vwgt[u[to]], vwgt[u[other]], pwgts[0], pwgts[1], pwgts[2]));
+            rcpp_warning("Moved %6"PRIDX" to %3"PRIDX", Gain: %5"PRIDX" [%5"PRIDX"] [%4"PRIDX" %4"PRIDX"] \t[%5"PRIDX" %5"PRIDX" %5"PRIDX"]\n", higain, to, g[to], g[other], vwgt[u[to]], vwgt[u[other]], pwgts[0], pwgts[1], pwgts[2]));
 
     }
 
@@ -237,7 +237,7 @@ void FM_2WayNodeRefine2Sided(ctrl_t *ctrl, graph_t *graph, idx_t niter)
     ASSERT(mincut == pwgts[2]);
 
     IFSET(ctrl->dbglvl, METIS_DBG_REFINE,
-      Rf_warning("\tMinimum sep: %6"PRIDX" at %5"PRIDX", PWGTS: [%6"PRIDX" %6"PRIDX"], NBND: %6"PRIDX"\n", mincut, mincutorder, pwgts[0], pwgts[1], nbnd));
+      rcpp_warning("\tMinimum sep: %6"PRIDX" at %5"PRIDX", PWGTS: [%6"PRIDX" %6"PRIDX"], NBND: %6"PRIDX"\n", mincut, mincutorder, pwgts[0], pwgts[1], nbnd));
 
     graph->mincut = mincut;
     graph->nbnd = nbnd;
@@ -295,7 +295,7 @@ void FM_2WayNodeRefine1Sided(ctrl_t *ctrl, graph_t *graph, idx_t niter)
   badmaxpwgt = (idx_t)(mult*(pwgts[0]+pwgts[1]+pwgts[2]));
 
   IFSET(ctrl->dbglvl, METIS_DBG_REFINE,
-    Rf_warning("Partitions-N1: [%6"PRIDX" %6"PRIDX"] Nv-Nb[%6"PRIDX" %6"PRIDX"]. ISep: %6"PRIDX"\n", pwgts[0], pwgts[1], graph->nvtxs, graph->nbnd, graph->mincut));
+    rcpp_warning("Partitions-N1: [%6"PRIDX" %6"PRIDX"] Nv-Nb[%6"PRIDX" %6"PRIDX"]. ISep: %6"PRIDX"\n", pwgts[0], pwgts[1], graph->nvtxs, graph->nbnd, graph->mincut));
 
   to = (pwgts[0] < pwgts[1] ? 1 : 0);
   for (pass=0; pass<2*niter; pass++) {  /* the 2*niter is for the two sides */
@@ -404,7 +404,7 @@ void FM_2WayNodeRefine1Sided(ctrl_t *ctrl, graph_t *graph, idx_t niter)
 
 
       IFSET(ctrl->dbglvl, METIS_DBG_MOVEINFO,
-            Rf_warning("Moved %6"PRIDX" to %3"PRIDX", Gain: %5"PRIDX" [%5"PRIDX"] \t[%5"PRIDX" %5"PRIDX" %5"PRIDX"] [%3"PRIDX" %2"PRIDX"]\n", 
+            rcpp_warning("Moved %6"PRIDX" to %3"PRIDX", Gain: %5"PRIDX" [%5"PRIDX"] \t[%5"PRIDX" %5"PRIDX" %5"PRIDX"] [%3"PRIDX" %2"PRIDX"]\n", 
                 higain, to, (vwgt[higain]-rinfo[higain].edegrees[other]), vwgt[higain], 
                 pwgts[0], pwgts[1], pwgts[2], nswaps, limit));
     }
@@ -454,7 +454,7 @@ void FM_2WayNodeRefine1Sided(ctrl_t *ctrl, graph_t *graph, idx_t niter)
     ASSERT(mincut == pwgts[2]);
 
     IFSET(ctrl->dbglvl, METIS_DBG_REFINE,
-      Rf_warning("\tMinimum sep: %6"PRIDX" at %5"PRIDX", PWGTS: [%6"PRIDX" %6"PRIDX"], NBND: %6"PRIDX"\n", mincut, mincutorder, pwgts[0], pwgts[1], nbnd));
+      rcpp_warning("\tMinimum sep: %6"PRIDX" at %5"PRIDX", PWGTS: [%6"PRIDX" %6"PRIDX"], NBND: %6"PRIDX"\n", mincut, mincutorder, pwgts[0], pwgts[1], nbnd));
 
     graph->mincut = mincut;
     graph->nbnd   = nbnd;
@@ -513,7 +513,7 @@ void FM_2WayNodeBalance(ctrl_t *ctrl, graph_t *graph)
   moved = iset(nvtxs, -1, iwspacemalloc(ctrl, nvtxs));
 
   IFSET(ctrl->dbglvl, METIS_DBG_REFINE,
-    Rf_warning("Partitions: [%6"PRIDX" %6"PRIDX"] Nv-Nb[%6"PRIDX" %6"PRIDX"]. ISep: %6"PRIDX" [B]\n", pwgts[0], pwgts[1], graph->nvtxs, graph->nbnd, graph->mincut));
+    rcpp_warning("Partitions: [%6"PRIDX" %6"PRIDX"] Nv-Nb[%6"PRIDX" %6"PRIDX"]. ISep: %6"PRIDX" [B]\n", pwgts[0], pwgts[1], graph->nvtxs, graph->nbnd, graph->mincut));
 
   nbnd = graph->nbnd;
   irandArrayPermute(nbnd, perm, nbnd, 1);
@@ -559,7 +559,7 @@ void FM_2WayNodeBalance(ctrl_t *ctrl, graph_t *graph)
     where[higain] = to;
 
     IFSET(ctrl->dbglvl, METIS_DBG_MOVEINFO,
-          Rf_warning("Moved %6"PRIDX" to %3"PRIDX", Gain: %3"PRIDX", \t[%5"PRIDX" %5"PRIDX" %5"PRIDX"]\n", higain, to, vwgt[higain]-rinfo[higain].edegrees[other], pwgts[0], pwgts[1], pwgts[2]));
+          rcpp_warning("Moved %6"PRIDX" to %3"PRIDX", Gain: %3"PRIDX", \t[%5"PRIDX" %5"PRIDX" %5"PRIDX"]\n", higain, to, vwgt[higain]-rinfo[higain].edegrees[other], pwgts[0], pwgts[1], pwgts[2]));
 
 
     /**********************************************************
@@ -600,7 +600,7 @@ void FM_2WayNodeBalance(ctrl_t *ctrl, graph_t *graph)
   }
 
   IFSET(ctrl->dbglvl, METIS_DBG_REFINE,
-    Rf_warning("\tBalanced sep: %6"PRIDX" at %4"PRIDX", PWGTS: [%6"PRIDX" %6"PRIDX"], NBND: %6"PRIDX"\n", pwgts[2], nswaps, pwgts[0], pwgts[1], nbnd));
+    rcpp_warning("\tBalanced sep: %6"PRIDX" at %4"PRIDX", PWGTS: [%6"PRIDX" %6"PRIDX"], NBND: %6"PRIDX"\n", pwgts[2], nswaps, pwgts[0], pwgts[1], nbnd));
 
   graph->mincut = pwgts[2];
   graph->nbnd   = nbnd;
