@@ -362,7 +362,7 @@ abort :                                           /* If overflow occured, resume
 #endif /* SCOTCH_DEBUG_VDGRAPH2 */
 
 if (grafptr->s.proclocnum == 0)
-Rf_warning("BROL " GNUMSTRING "," GNUMSTRING "," GNUMSTRING "(" GNUMSTRING ")\n",
+rcpp_warning("BROL " GNUMSTRING "," GNUMSTRING "," GNUMSTRING "(" GNUMSTRING ")\n",
          (Gnum) grafptr->compglbload[0],
          (Gnum) grafptr->compglbload[1],
          (Gnum) grafptr->compglbload[2],
